@@ -71,9 +71,9 @@ static enum SHAversion which_cl_hash(int which_hash)
  * Portable replacement for 'strdup()'
  *
  * 'strdup()' requires SUSv2, XSI extension or POSIX.1-2008
- * http://pubs.opengroup.org/onlinepubs/007908799/xsh/strdup.html
- * http://pubs.opengroup.org/onlinepubs/009695399/functions/strdup.html
- * http://pubs.opengroup.org/onlinepubs/9699919799/functions/strdup.html
+ * https://pubs.opengroup.org/onlinepubs/007908799/xsh/strdup.html
+ * https://pubs.opengroup.org/onlinepubs/009695399/functions/strdup.html
+ * https://pubs.opengroup.org/onlinepubs/9699919799/functions/strdup.html
  *
  * Note:
  * 'malloc()' already gives the correct return (and 'errno') values required by
@@ -233,7 +233,8 @@ char *cl_get_key(int which_hash, const unsigned char *secret, size_t seclen,
    if ((size_t) INT_MAX < msglen || (size_t) INT_MAX < seclen)
       return NULL;
 
-   if (hmac(which_sha, message, (int) msglen, secret, (int) seclen, hmacbuff)
+   if (RFC2104Hmac(which_sha, message, (int) msglen, secret, (int) seclen,
+                   hmacbuff)
        != shaSuccess)
       return NULL;
 
